@@ -28,7 +28,7 @@ class Collection:
         data = {
             'secret': self.__api_key__,
             'collectionName': self.__collection_name__,
-            'doc': edict(doc),
+            'doc': doc.__dict__,
             'id': doc_id
         }
         response = requests.post(url, json=data)
